@@ -5,7 +5,7 @@ use warnings;
 use parent qw(Exporter);
 use Try::Tiny qw(try catch finally);
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 our @EXPORT_OK = qw( try catch finally try_chain $call_m $fetch_i $fetch_k );
 
@@ -63,19 +63,43 @@ Try::Chain - Call method, hash and/or array chains with break on undef
 
 =head1 VERSION
 
-0.002
+0.003
 
 =head1 SYNOPSIS
 
 The module exports:
 
-    try       - imported from Try::Tiny
-    catch     - imported from Try::Tiny
-    finally   - imported from Try::Tiny
-    try_chain - implemented here to call a complete chain or break
-    $call_m   - implemented here to call a method or break
-    $fetch_i  - implemented here to fetch an array index or break
-    $fetch_k  - implemented here to fetch a hash key or break
+=over
+
+=item try
+
+imported from Try::Tiny
+
+=item catch
+
+imported from Try::Tiny
+
+=item finally
+
+imported from Try::Tiny
+
+=item try_chain
+
+implemented here to call a complete chain or break
+
+=item $call_m
+
+implemented here to call a method or break
+
+=item $fetch_i
+
+implemented here to fetch an array index or break
+
+=item $fetch_k
+
+implemented here to fetch a hash key or break
+
+=back
 
 Import what needed. The following code describes the full import:
 
@@ -204,7 +228,7 @@ Calls the next method if possible.
 
 Calls the next index of an array reference if possible.
 
-=head2 sub $fetch_i
+=head2 sub $fetch_k
 
 Calls the next key of a hash reference if possible.
 
